# Generated by roxygen2: do not edit by hand

S3method(print,NRtest)
export(BS1996.TS.NABT)
export(CCXH2024.GLHTBF.2cNRT)
export(CQ2010.TSBF.NABT)
export(FHW2004.GLHT.NABT)
export(LHNB2025.GLHTBF.NABT)
export(NRtest.object)
export(S2007.ks.NABT)
export(SD2008.TS.NABT)
export(SF2006.GLHT.NABT)
export(SKK2013.TSBF.NABT)
export(WZ2026.GLHTBF.2cNRT)
export(YS2012.GLHT.NABT)
export(ZGZ2017.GLHT.2cNRT)
export(ZGZ2017.GLHTBF.NABT)
export(ZGZC2020.TS.2cNRT)
export(ZWZ2023.TSBF.2cNRT)
export(ZZ2022.GLHT.3cNRT)
export(ZZ2022.GLHTBF.3cNRT)
export(ZZ2022.TS.3cNRT)
export(ZZ2022.TSBF.3cNRT)
export(ZZG2022.GLHTBF.2cNRT)
export(ZZGZ2021.TSBF.2cNRT)
export(ZZZ2020.TS.2cNRT)
export(ZZZ2022.GLHT.2cNRT)
export(ZZZ2023.TSBF.2cNRT)
import(expm)
import(readr)
importFrom(Rcpp,evalCpp)
importFrom(Rcpp,sourceCpp)
importFrom(Rdpack,reprompt)
importFrom(readr,read_csv)
importFrom(stats,pchisq)
importFrom(stats,pf)
importFrom(stats,pnorm)
importFrom(stats,qchisq)
importFrom(stats,setNames)
importFrom(utils,packageVersion)
useDynLib(HDNRA, .registration = TRUE)
