#' @keywords internal
"_PACKAGE"

#' @import expm
#' @import readr
#' @importFrom stats pnorm
#' @importFrom stats pchisq
#' @importFrom Rcpp evalCpp
#' @importFrom readr read_csv
#' @importFrom stats pf
#' @importFrom Rdpack reprompt
#' @importFrom stats setNames


## usethis namespace: start
#' @importFrom Rcpp sourceCpp
## usethis namespace: end
NULL

## usethis namespace: start
#' @useDynLib HDNRA, .registration = TRUE
## usethis namespace: end
NULL

