# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

bs1996_ts_nabt_cpp <- function(y1, y2) {
    .Call(`_HDNRA_bs1996_ts_nabt_cpp`, y1, y2)
}

cq2010_tsbf_nabt_cpp <- function(y1, y2) {
    .Call(`_HDNRA_cq2010_tsbf_nabt_cpp`, y1, y2)
}

zgzc2020_ts_2cnrt_cpp <- function(y1, y2) {
    .Call(`_HDNRA_zgzc2020_ts_2cnrt_cpp`, y1, y2)
}

zzgz2021_tsbf_2cnrt_cpp <- function(y1, y2) {
    .Call(`_HDNRA_zzgz2021_tsbf_2cnrt_cpp`, y1, y2)
}

zz2022_ts_3cnrt_cpp <- function(y1, y2) {
    .Call(`_HDNRA_zz2022_ts_3cnrt_cpp`, y1, y2)
}

zz2022_tsbf_3cnrt_cpp <- function(y1, y2) {
    .Call(`_HDNRA_zz2022_tsbf_3cnrt_cpp`, y1, y2)
}

zwz2023_tsbf_2cnrt_cpp <- function(y1, y2) {
    .Call(`_HDNRA_zwz2023_tsbf_2cnrt_cpp`, y1, y2)
}

sd2008_ts_nabt_cpp <- function(y1, y2) {
    .Call(`_HDNRA_sd2008_ts_nabt_cpp`, y1, y2)
}

skk2013_tsbf_nabt_cpp <- function(y1, y2) {
    .Call(`_HDNRA_skk2013_tsbf_nabt_cpp`, y1, y2)
}

zzz2020_ts_2cnrt_cpp <- function(y1, y2) {
    .Call(`_HDNRA_zzz2020_ts_2cnrt_cpp`, y1, y2)
}

zzz2023_tsbf_2cnrt_cpp <- function(y1, y2) {
    .Call(`_HDNRA_zzz2023_tsbf_2cnrt_cpp`, y1, y2)
}

s2007_ks_nabt_cpp <- function(Y, n, p) {
    .Call(`_HDNRA_s2007_ks_nabt_cpp`, Y, n, p)
}

fhw2004_glht_nabt_cpp <- function(Y, X, C, n, p) {
    .Call(`_HDNRA_fhw2004_glht_nabt_cpp`, Y, X, C, n, p)
}

sf2006_glht_nabt_cpp <- function(Y, X, C, n, p) {
    .Call(`_HDNRA_sf2006_glht_nabt_cpp`, Y, X, C, n, p)
}

ys2012_glht_nabt_cpp <- function(Y, X, C, n, p) {
    .Call(`_HDNRA_ys2012_glht_nabt_cpp`, Y, X, C, n, p)
}

zgz2017_glhtbf_nabt_cpp <- function(Y, tG, n, p) {
    .Call(`_HDNRA_zgz2017_glhtbf_nabt_cpp`, Y, tG, n, p)
}

zgz2017_glht_2cnrt_cpp <- function(Y, tG, n, p) {
    .Call(`_HDNRA_zgz2017_glht_2cnrt_cpp`, Y, tG, n, p)
}

zzg2022_glhtbf_2cnrt_cpp <- function(Y, tG, n, p) {
    .Call(`_HDNRA_zzg2022_glhtbf_2cnrt_cpp`, Y, tG, n, p)
}

zz2022_glht_3cnrt_cpp <- function(Y, tG, n, p) {
    .Call(`_HDNRA_zz2022_glht_3cnrt_cpp`, Y, tG, n, p)
}

zz2022_glhtbf_3cnrt_cpp <- function(Y, tG, n, p) {
    .Call(`_HDNRA_zz2022_glhtbf_3cnrt_cpp`, Y, tG, n, p)
}

zzz2022_glht_2cnrt_cpp <- function(Y, X, C, n, p) {
    .Call(`_HDNRA_zzz2022_glht_2cnrt_cpp`, Y, X, C, n, p)
}

wz2026_glhtbf_2cnrt_cpp <- function(Y, tG, n, p) {
    .Call(`_HDNRA_wz2026_glhtbf_2cnrt_cpp`, Y, tG, n, p)
}

random_integration_test_cpp <- function(Y, B, O, A, n, p) {
    .Call(`_HDNRA_random_integration_test_cpp`, Y, B, O, A, n, p)
}

cao2024_scale_invariant_cpp <- function(Y, B, n, p) {
    .Call(`_HDNRA_cao2024_scale_invariant_cpp`, Y, B, n, p)
}

