% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/LHNB2025.GLHTBF.NABT.R
\name{LHNB2025.GLHTBF.NABT}
\alias{LHNB2025.GLHTBF.NABT}
\title{Normal-approximation-based test for k-sample linear hypothesis via random integration proposed by Li et al. (2025)}
\usage{
LHNB2025.GLHTBF.NABT(Y, B, O, A, n, p)
}
\arguments{
\item{Y}{A list of \eqn{k} data matrices. The \eqn{i}th element represents the data matrix
(\eqn{n_i \times p}) from the \eqn{i}th population with each row representing a \eqn{p}-dimensional observation.}

\item{B}{A vector of \eqn{k} coefficients \eqn{(B_1,\ldots,B_k)} specifying the linear combination of group mean vectors.}

\item{O}{A length-\eqn{p} vector used to form \eqn{\Omega = \mathrm{diag}(O_1^2,\ldots,O_p^2)}.}

\item{A}{A length-\eqn{p} vector used in \eqn{W = \Omega + A A^\top}.}

\item{n}{A vector of \eqn{k} sample sizes. The \eqn{i}th element represents the sample size of group \eqn{i}, \eqn{n_i}.}

\item{p}{The dimension of data.}
}
\value{
A list of class \code{"NRtest"} containing the results of the hypothesis test.
}
\description{
Li et al. (2025)'s test for general linear hypothesis testing (GLHT) problem for high-dimensional data under heteroscedasticity.
}
\details{
Suppose we have \eqn{k} independent high-dimensional samples
\deqn{\boldsymbol{Y}_{i1},\ldots,\boldsymbol{Y}_{in_i}\ \text{are i.i.d. with}\ \mathrm{E}(\boldsymbol{Y}_{i1})=\boldsymbol{\mu}_i,\
\mathrm{Cov}(\boldsymbol{Y}_{i1})=\boldsymbol{\Sigma}_i,\ i=1,\ldots,k,}
where the covariance matrices \eqn{\boldsymbol{\Sigma}_i} may differ across groups.

It is of interest to test the k-sample linear hypothesis
\deqn{H_0:\ \sum_{i=1}^k B_i\boldsymbol{\mu}_i=\boldsymbol{0}\quad \text{vs.}\quad H_1:\ \sum_{i=1}^k B_i\boldsymbol{\mu}_i\neq\boldsymbol{0}.}

Li et al. (2025) proposed a random-integration-based U-statistic \eqn{T_n} (Eq. (5) in the paper),
constructed using the weight matrix \eqn{\boldsymbol{W}=\boldsymbol{\Omega}+\boldsymbol{A}\boldsymbol{A}^\top} with
\eqn{\boldsymbol{\Omega}=\mathrm{diag}(O_1^2,\ldots,O_p^2)}.
They showed that the standardized statistic \eqn{Z=T_n/\sqrt{\hat{\sigma}^2}} is approximated by \eqn{N(0,1)} under \eqn{H_0}.

A recommended default choice of tuning parameters is of the form
\eqn{A_1=\cdots=A_p=\sqrt{5}\,p^{-3/8}} and \eqn{O_k=\sqrt{\epsilon\left(1+\frac{2k}{3p}\right)}}, \eqn{k=1,\ldots,p}.
}
\examples{
\donttest{
library("HDNRA")
data("corneal")

# corneal: 150 x p, split into 4 groups (n_i x p)
group1 <- as.matrix(corneal[1:43,  ])      # normal
group2 <- as.matrix(corneal[44:57, ])      # unilateral suspect
group3 <- as.matrix(corneal[58:78, ])      # suspect map
group4 <- as.matrix(corneal[79:150,])      # clinical keratoconus

Y <- list(group2, group3, group4)
n <- c(nrow(group2), nrow(group3), nrow(group4))
p <- ncol(group2)

# One linear combination (example): B = (4, -1.5, -2.5)
B <- c(4, -1.5, -2.5)

# Paper-style tuning parameters (example with eps = 2)
A <- rep(sqrt(5) * p^(-3/8), p)
O <- sqrt(2) * (1 + 2*(1:p)/(3*p))

LHNB2025.GLHTBF.NABT(Y, B, O, A, n, p)
}


}
\references{
\insertRef{li2025test}{HDNRA}
}
\concept{glht}
